==> babel-plugin-cx-16.5.0.tgz: package/index.js <==
"use strict";

function property(t, name, value) {
   if (name.namespace && name.namespace.name) {
      return t.objectProperty(t.stringLiteral(name.namespace.name), t.objectExpression([
         t.objectProperty(t.stringLiteral(name.name.name), value)
      ]));
   }

   return t.objectProperty(t.stringLiteral(name.name), value);
}

function processAttribute(t, attribute) {
   if (attribute.type === 'JSXAttribute') {
      switch (attribute.value.type) {
         case 'JSXExpressionContainer':
            return property(t, attribute.name, attribute.value.expression);
      }

      return property(t, attribute.name, attribute.value);
   }

   return false;
}

function processChild(t, child, root) {

   switch (child.type) {
      case 'JSXElement':
         return processElement(t, child, root);

      case 'JSXText':
         return t.stringLiteral(child.value)
      //return t.objectExpression([
      //   t.objectProperty(t.stringLiteral("type"), t.stringLiteral("statictext")),
      //   t.objectProperty(t.stringLiteral("text"), t.stringLiteral(child.value))
      //]);
   }

   return child;
}

function processElement(t, element, root) {
   if (element.type === "JSXElement") {
      if (element.openingElement) {
         var tagName = element.openingElement.name.name;
         if (tagName != "cx" && root.root)
            return false;

         var children;

         if (root.root) {
            root.root = false;
            if (element.children != null) {
               children = element.children.filter(c=>c.type == "JSXElement").map(c=>processElement(t, c, root));
               if (children.length > 1)
                  return t.arrayExpression(children);

               if (children.length == 1)
                  return children[0];
            }
            return t.nullLiteral();
         }

         var attrs = [];
         attrs.push(t.objectProperty(t.stringLiteral('type'), t.stringLiteral(tagName.toLowerCase())));

         if (element.openingElement.attributes && element.openingElement.attributes.length) {
            for (var i = 0; i < element.openingElement.attributes.length; i++) {
               var a = processAttribute(t, element.openingElement.attributes[i]);
               if (a)
                  attrs.push(a);
            }
         }

         if (element.children != null && element.children.length) {
            var children = [];
            for (var i = 0; i < element.children.length; i++) {
               var c = processChild(t, element.children[i], root);
               if (c)
                  children.push(c);
            }
            if (children.length)
               attrs.push(t.objectProperty(t.stringLiteral('children'), t.arrayExpression(children)));
         }

         return t.objectExpression(attrs);
      }
   }
}

module.exports = function(options) {
   var t = options.types;

   return {
      visitor: {
         JSXElement: {
            enter(path, scope) {
               var opts = scope.opts;
               var node = path.node;

               if (node.root) {
                  return;
               }

               var root = {
                  root: true
               };

               var config = processElement(t, node, root, null);

               if (config) {
                  path.replaceWith(config);
                  node.root = true;
               }
            }
         }
      },
      inherits: require("babel-plugin-syntax-jsx")
   }
};

==> babel-plugin-cx-16.5.2.tgz: package/index.js <==
"use strict";

function property(t, name, value) {
   if (name.namespace && name.namespace.name) {
      return t.objectProperty(t.stringLiteral(name.namespace.name), t.objectExpression([
         t.objectProperty(t.stringLiteral(name.name.name), value)
      ]));
   }

   return t.objectProperty(t.stringLiteral(name.name), value);
}

function elementName(name) {
   if (name.name)
      return name.name;
   if (name.object)
      return elementName(name.object) + '.' + elementName(name.property);
   throw new Error('Could not calculate name.');
}

function processAttribute(t, attribute) {
   if (attribute.type === 'JSXAttribute') {
      switch (attribute.value.type) {
         case 'JSXExpressionContainer':
            return property(t, attribute.name, attribute.value.expression);
      }

      return property(t, attribute.name, attribute.value);
   }

   return false;
}

function processChild(t, child, root) {

   switch (child.type) {
      case 'JSXElement':
         return processElement(t, child, root);

      case 'JSXText':
         return t.stringLiteral(child.value);
      //return t.objectExpression([
      //   t.objectProperty(t.stringLiteral("type"), t.stringLiteral("statictext")),
      //   t.objectProperty(t.stringLiteral("text"), t.stringLiteral(child.value))
      //]);

      case 'JSXExpressionContainer':
         return child.expression;
   }

   return child;
}

function processElement(t, element, root) {
   if (element.type === "JSXElement") {
      if (element.openingElement) {
         var tagName = elementName(element.openingElement.name);
         if (tagName != "cx" && root.root)
            return false;

         var children;

         if (root.root) {
            root.root = false;
            if (element.children != null) {
               children = element.children.filter(c=>c.type == "JSXElement").map(c=>processElement(t, c, root));
               if (children.length > 1)
                  return t.arrayExpression(children);

               if (children.length == 1)
                  return children[0];
            }
            return t.nullLiteral();
         }

         var attrs = [];
         //attrs.push(t.objectProperty(t.stringLiteral('type'), t.stringLiteral(tagName.toLowerCase())));
         if (tagName[0].toLowerCase() == tagName[0] && tagName.indexOf('.')==-1)
            attrs.push(t.objectProperty(t.stringLiteral('$type'), t.stringLiteral(tagName)));
         else {
            debugger;
            attrs.push(t.objectProperty(t.stringLiteral('$type'), element.openingElement.name));
         }
         var attrNames = [];

         if (element.openingElement.attributes && element.openingElement.attributes.length) {
            for (var i = 0; i < element.openingElement.attributes.length; i++) {
               var a = processAttribute(t, element.openingElement.attributes[i]);
               if (a) {
                  attrs.push(a);
                  attrNames.push(a.key.value);
               }
            }
         }

         if (attrNames.length>0)
            attrs.push(t.objectProperty(t.stringLiteral('jsxAttributes'), t.arrayExpression(attrNames.map(name=>t.stringLiteral(name)))));

         if (element.children != null && element.children.length) {
            var children = [];
            for (var i = 0; i < element.children.length; i++) {
               var c = processChild(t, element.children[i], root);
               if (c)
                  children.push(c);
            }
            if (children.length)
               attrs.push(t.objectProperty(t.stringLiteral('children'), t.arrayExpression(children)));
         }

         return t.objectExpression(attrs);
      }
   }
}

module.exports = function(options) {
   var t = options.types;

   return {
      visitor: {
         JSXElement: {
            enter(path, scope) {
               var opts = scope.opts;
               var node = path.node;

               if (node.root) {
                  return;
               }

               var root = {
                  root: true
               };

               var config = processElement(t, node, root, null);

               if (config) {
                  path.replaceWith(config);
                  node.root = true;
               }
            }
         }
      },
      inherits: require("babel-plugin-syntax-jsx")
   }
};
